@@ -27,4 +27,6 @@ pub mod binary_tree;
 /// DSU (disjoint-set-union)
 pub mod dsu;
 /// Sheduling algorithms
-pub mod sheduling;
\ No newline at end of file
+pub mod sheduling;
+/// Sorting algorithms
+pub mod sort;
\ No newline at end of file
